@@ -11,8 +11,12 @@ from .html import html_minify
 logger = logging.getLogger(__name__)
 
 
-def html_beautify(raw, settings):
-    return BeautifulSoup(raw, "html.parser").prettify(), None
+space_re = re.compile(r"^(\s*)", re.MULTILINE)
+
+
+def html_beautify(raw, settings, encoding=None, formatter="minimal", indents=4):
+    s = BeautifulSoup(raw, "html.parser")
+    return space_re.sub(r"\1" * indents, s.prettify(encoding=encoding, formatter=formatter)), None
 
 
 class Handler:
