@@ -14,12 +14,18 @@ import sys
 from .modes import Mode
 from .handlers import HandlerManager
 
+from pyfiglet import figlet_format
+
+
 from . import __version__
 
 logger = setup_logging(__name__)
 
 nproc = cpu_count()
 
+logo = figlet_format("web-minify", font="smslant") + f"v{__version__}"
+
+
 ##############################################################################
 
 
@@ -30,6 +36,7 @@ def parse_arguments(defaults):
         formatter_class=RawDescriptionHelpFormatter,
         epilog=f"""
     ---------------------------------------------------------
+{logo}
 
     Process all CSS/SASS/HTML/JS/SVG/PNG/JPEG found at input,
     either in single file or recursively.
@@ -62,8 +69,6 @@ def parse_arguments(defaults):
     + {{PATH}}
     + {{BASE}}
  
-    web-minify version {__version__}
- 
 """,
     )
 
@@ -172,6 +177,7 @@ def main():
         mode = settings.get("mode", "minify")
         settings["mode"] = mode.value if type(mode) is Mode else mode
         processor = Processor(settings)
+        logger.info(f"\n{logo}\n")
         res, msg = processor.sanity_checks()
         if not res:
             logger.error(f"Sanity check failed: {msg}, quitting...")
