@@ -8,6 +8,8 @@ from .handlers import HandlerManager
 from .time import human_delta
 from .modes import Mode
 
+now = time.time()
+
 # from multiprocessing import Pool, cpu_count
 from pathos.multiprocessing import ProcessingPool as Pool
 
@@ -15,7 +17,7 @@ import logging
 
 logger = logging.getLogger(__name__)
 
-now = datetime.datetime.now()
+now = datetime.datetime.utcnow().timestamp()
 
 gzip_suffix = ".gz"
 
@@ -28,6 +30,11 @@ def append_and_return(raw, item):
     return raw
 
 
+def b2s(b):
+    # return "✅" if b else "❌"
+    return "☑️" if b else "-"
+
+
 class Processor:
     def __init__(self, settings: dict):
         self.settings = settings
@@ -80,7 +87,7 @@ class Processor:
             return (False, f"The input '{self.input}' is a subpath of output '{self.output}'")
         return True, None
 
-    def process_file(self, input_path: str, output_path: str):
+    def process_file(self, input_path: str, output_path: str, now=now):
         encoding = "utf-8"
         # fmt:off
         status={
@@ -95,8 +102,6 @@ class Processor:
         }
         # fmt:on
         messages = []
-        if self.verbose:
-            logger.info(f"Processing '{input_path}' -->[{self.mode.value}]--> '{output_path}'")
         if not input_path:
             return False, status, append_and_return(messages, "No input path specified")
         if not output_path:
@@ -150,7 +155,10 @@ class Processor:
             status["empty"] = True
         processed_content = None
         handler_errors = None
-        do_copy = handler is None or vip_file or (handler.name() in self.handler_names and self.settings.get(f"disable_type_{handler.name()}", False)) or (extension in self.valid_extensions and self.settings.get(f"disable_suffix_{extension}", False))
+        handler_name = handler.name() if handler else None
+        handler_disabled = handler_name in self.handler_names and self.settings.get(f"disable_type_{handler.name()}", False)
+        extension_disabled = extension in self.valid_extensions and self.settings.get(f"disable_suffix_{extension}", False)
+        do_copy = handler is None or vip_file or handler_disabled or extension_disabled
         if do_copy:
             # Perform copy
             if self.verbose:
@@ -167,6 +175,8 @@ class Processor:
         if None == processed_content:
             messages = append_and_return(messages, f"Processed file was empty")
             status["empty"] = True
+        content_changed = original_content != processed_content
+        status["changed"] = content_changed
         try:
             if not self.dry_run:
                 with open(output_path, "wb") if is_binary else open(output_path, "w", encoding=encoding) as file:
@@ -178,7 +188,9 @@ class Processor:
             return False, status, append_and_return(messages, f"Could not write data to output file: {err}")
         try:
             if not self.dry_run:
-                os.utime(output_path, (input_mtime, input_mtime))
+                # If source and destination is identical then there will be no change in time, so in that case we induce it  by using "now"
+                final_time = input_mtime if output_path is not input_path else now
+                os.utime(output_path, (final_time, final_time))
         except Exception as err:
             return False, status, append_and_return(messages, f"Could not modify date of output file: {err}")
         if self.gzip:
@@ -263,7 +275,7 @@ class Processor:
         return cols
 
     def log_table(self, name, table, remove=[]):
-        heads = ["extension", "type", "success", "failed", "written", "copied", "binary", "gzip", "skipped", "empty", "time", "slow"]
+        heads = ["extension", "type", "success", "failed", "written", "changed", "copied", "binary", "gzip", "skipped", "empty", "time", "slow"]
         # self.table_heads(table)
         heads = [head for head in heads if head not in remove]
         norm = self.normalize_tabdata(table, heads)
@@ -286,14 +298,12 @@ class Processor:
                 if t is datetime.timedelta:
                     value = human_delta(value)
                 elif t is bool:
-                    value = "✅" if value else "❌"
+                    value = b2s(value)
                 vals.append(value)
             logger.info(fmt.format(*vals))
         logger.info("+" + "-" * (lt - 2) + "+")
 
     def log_summary(self, summary):
-        logger.info(f"")
-        logger.info(f"SUMMARY:")
         ft = {"by_extension": ["type"], "by_type": ["extension"]}
         for k, v in ft.items():
             table = summary.get(k, {}.copy())
@@ -310,14 +320,15 @@ class Processor:
         if self.dry_run:
             logger.info(f"Dry run enabled, changes will NOT be commited to filesystem")
         if self.nproc > 1:
-            logger.info(f"Doing multiprocessing with {self.nproc} cores")
+            logger.info(f"Doing multiprocessing on {len(files_list)} files with {self.nproc} cores...")
             with Pool(self.nproc) as pool:
                 results = pool.map(self.process_files_list_item_wrapper, files_list)
         else:
-            logger.info(f"Doing sequential processing")
+            logger.info(f"Doing sequential processing on {len(files_list)} files...")
             for item in files_list:
                 result = self.process_files_list_item_wrapper(item)
                 results.append(result)
+        logger.info(f"\nDONE!\n")
         # Summarize results
         by_extension = {}
         by_type = {}
@@ -330,6 +341,7 @@ class Processor:
           , 'failed'
           , "copied"
           , "written"
+          , "changed"
           , "skipped"
           , "empty"
           , "binary"
@@ -344,6 +356,7 @@ class Processor:
             , "failed": 0
             , "copied": 0
             , "written": 0
+            , "changed": 0
             , "skipped": 0
             , "empty": 0
             , "binary": 0
@@ -358,8 +371,48 @@ class Processor:
         keys.remove("type")
         total = "total"
         by_key = {}
+        failed_ct = 0
+        sp = " " * 2
+
+        def vertical_header():
+            logger.info("")
+            stati = ["success", "copied", "written", "changed", "skipped", "empty", "binary", "gzip", "slow"]
+            # stati=["success", "gzip"]
+            longest = 0
+            for s in stati:
+                longest = len(s) if len(s) > longest else longest
+            r = list(range(longest))
+            # logger.info(f"longest={longest}, r={r}")
+            for y in r:
+                line = ""
+                for s in stati:
+                    sl = len(s)
+                    d = longest - len(s)
+                    cond = y >= d
+                    # logger.info(f"s={s}, sl={sl}, y={y}, longest={longest}, d={d}, cond={cond}")
+                    line += s[y - d] if cond else " "
+                    line += sp
+                logger.info(line)
+
+        if self.verbose:
+            # logger.info(f"Processing '{input_path}' -->[{self.mode.value}]--> '{output_path}'")
+            vertical_header()
+            fct = 0
+            header_interval = 10
+            for result in results:
+                if fct > header_interval:
+                    fct -= header_interval
+                    vertical_header()
+                s = result.get("status")
+                output_path = result.get("output_path")
+                logger.info(f"{b2s(s['success'])}{sp}{b2s(s['copied'])}{sp}{b2s(s['written'])}{sp}{b2s(s['changed'])}{sp}{b2s(s['skipped'])}{sp}{b2s(s['empty'])}{sp}{b2s(s['binary'])}{sp}{b2s(s['gzip'])}{sp}{b2s(s['slow'])}{sp}'{output_path}'")
+                fct += 1
+
         for result in results:
             status = result.get("status")
+            failed = status.get("failed")
+            if failed:
+                failed_ct += 1
             extension = status.get("extension") or "?"
             handler_type = status.get("type") or "?"
             extension_item = by_extension.get(extension, def_item.copy())
@@ -404,7 +457,6 @@ class Processor:
         summary = {"by_extension": by_extension, "by_type": by_type}
         end_time = datetime.datetime.now()
         interval = end_time - start_time
-        logger.info(f"Processing of {len(files_list)} files generated {len(messages)} message(s) and took {human_delta(interval)} total")
         if messages:
             logger.warning(f"Messages encountered were:")
             for message, all in messages.items():
@@ -417,18 +469,19 @@ class Processor:
                     logger.warning(f"    ... and {count-show_count} more")
                 logger.warning("")
         self.log_summary(summary)
+        logger.info(f"Performing {self.mode.value} on {len(files_list)} files generated {len(messages)} message(s) and took {human_delta(interval)} total\n")
+        if failed_ct > 0:
+            logger.error(f"NOTE: {failed_ct} errors occured\n")
         return True
 
     def _process_existing_dir_to_existing_dir(self):
         input_paths = generate_file_list(self.input, tuple(self.valid_extensions))
-        # logger.info(pprint.pformat(input_paths))
         files_list = []
         for input_path in input_paths:
             common = os.path.commonpath((os.path.abspath(self.output), os.path.abspath(input_path)))
             rel = os.path.relpath(os.path.abspath(input_path), os.path.abspath(self.input))
             output_path = os.path.join(os.path.abspath(self.output), rel)
             files_list.append({"input_path": input_path, "output_path": output_path})
-        # logger.info(pprint.pformat(files_list))
         return files_list
 
     def _process_existing_dir_to_new_dir(self):
@@ -439,24 +492,18 @@ class Processor:
 
     def _process_existing_dir_overwrite(self):
         input_paths = generate_file_list(self.input, tuple(self.valid_extensions))
-        # logger.info(pprint.pformat(input_paths))
         files_list = []
         for input_path in input_paths:
             files_list.append({"input_path": input_path, "output_path": input_path})
-        # logger.info(pprint.pformat(files_list))
         return files_list
 
     def _process_existing_file(self):
         files_list = [{"input_path": os.path.abspath(self.input), "output_path": os.path.abspath(self.output)}]
-        logger.info("LIST for _process_existing_file")
-        logger.info(pprint.pformat(files_list))
         return files_list
 
     def _process_existing_file_to_dir(self):
         head, tail = os.path.split(os.path.abspath(self.input))
         files_list = [{"input_path": os.path.abspath(self.input), "output_path": os.path.join(os.path.abspath(self.output), tail)}]
-        logger.info("LIST for _process_existing_file_to_dir")
-        logger.info(pprint.pformat(files_list))
         return files_list
 
     def process_files(self):
